@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: envManager.php 5216 2012-09-18 06:54:40Z fishbone $
+ * @version    SVN: $Id: envManager.php 5558 2013-01-16 11:29:58Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/version.php');	// システムバージョンクラス
@@ -66,7 +66,9 @@ class EnvManager extends Core
 	private $userAgent = array();	// アクセス端末の情報
 	private $joomlaMenuContent;		// Joomla!v1.5用メニューコンテンツ
 	private $joomlaMenuData;		// Joomla!v2.5用メニュー階層データ
+	private $joomlaViewData;		// Joomla!ビュー作成用データ
 	private $defaultLacaleArray;	// デフォルトのロケール取得用
+	private $selectedMenuItems = array();				// 現在選択中のメニュー項目
 	const DEFAULT_LOCALE = 'ja_JP';			// デフォルトロケール
 	const DEFAULT_CSV_DELIM_CODE = 'csv_delim_code';		// デフォルトのCSV区切り文字コード
 	const DEFAULT_CSV_NL_CODE = 'csv_nl_code';		// デフォルトのCSV改行コード
@@ -2056,6 +2058,25 @@ class EnvManager extends Core
 		}
 		return $this->siteEmail;
 	}
+	/**
+	 * 現在選択中のメニュー項目を設定
+	 *
+	 * @param array $menuItemData	メニュー項目データ(title=タイトル、url=リンク)の配列
+	 * @return 						なし
+	 */
+	public function setSelectedMenuItems($menuItemData)
+	{
+		$this->selectedMenuItems = $menuItemData;				// 現在選択中のメニュー項目
+	}
+	/**
+	 * 現在選択中のメニュー項目を取得
+	 *
+	 * @return array				メニュー項目データ(title=タイトル、url=リンク)
+	 */
+	public function getSelectedMenuItems()
+	{
+		return $this->selectedMenuItems;				// 現在選択中のメニュー項目
+	}
 	/**
 	 * デフォルトCSV区切り文字コードを取得
 	 *
@@ -2384,5 +2405,24 @@ class EnvManager extends Core
 	{
 		return $this->joomlaMenuData;
 	}
+	/**
+	 * Joomla!用ビュー作成用データを設定
+	 *
+	 * @param array $viewData		ビュー作成データ
+	 * @return 						なし
+	 */
+	public function setJoomlaViewData($viewData)
+	{
+		$this->joomlaViewData = $viewData;
+	}
+	/**
+	 * Joomla!用ビュー作成用データを取得
+	 *
+	 * @return array		メニューデータ
+	 */
+	public function getJoomlaViewData()
+	{
+		return $this->joomlaViewData;
+	}
 }
 ?>
