@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2012 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 5107 2012-08-13 06:04:45Z fishbone $
+ * @version    SVN: $Id: admin_mainAdjustwidgetWidgetContainer.php 5467 2012-12-13 14:10:24Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/admin_mainBaseWidgetContainer.php');
@@ -26,6 +26,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 	private $exceptPageArray;		// 例外ページ
 	const CALENDAR_ICON_FILE = '/images/system/calendar.png';		// カレンダーアイコン
 	const ITEM_HEAD_EXCEPT_PAGE = 'item_except_';			// 例外ページサブIDの項目名ヘッダ
+	const WIDGET_CSS_CLASS_HEAD = 'm3_';			// ウィジェットCSSクラスのヘッダ部
 	
 	/**
 	 * コンストラクタ
@@ -110,6 +111,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		// 「その他」設定
 		$shared = ($request->trimValueOf('item_shared') == 'on') ? 1 : 0;		// 共通属性があるかどうか
 		$viewControlType = $request->trimValueOf('item_view_type');			// 表示制御タイプ
+		$cssClassSuffix = $request->trimValueOf('item_css_class_suffix');			// 追加CSSクラスサフィックス
 		
 		// 例外ページ
 		$this->db->getPageIdRecords(1/*ページサブID*/, $this->subIdRecords);
@@ -182,6 +184,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			if (!empty($start_date) && !empty($end_date)){
 				if (strtotime($start_date . ' ' . $start_time) >= strtotime($end_date . ' ' . $end_time)) $this->setUserErrorMsg($this->_('Invalid view term.'));		// 表示期間が不正です
 			}
+			$this->checkSingleByte($cssClassSuffix, '追加CSSクラス');			// 追加CSSクラスサフィックス
 			
 			// エラーなしの場合は、データを更新
 			if ($this->getMsgCount() == 0){
@@ -207,6 +210,10 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				$exceptPageStr = '';
 				if (!empty($this->exceptPageArray)) $exceptPageStr = implode(',', $this->exceptPageArray);
 				$updateData['pd_except_sub_id'] = $exceptPageStr;
+				
+				// 追加CSSクラス
+				$updateData['pd_suffix'] = $cssClassSuffix;			// 追加CSSクラスサフィックス
+				
 				$ret = $this->db->updatePageDefRecord($defSerial, $updateData);
 				
 				// ページ共通属性を更新
@@ -253,6 +260,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 			$start_time = '';	// 公開期間開始時間
 			$end_date = '';	// 公開期間終了日
 			$end_time = '';	// 公開期間終了時間
+			$cssClassSuffix = '';			// 追加CSSクラスサフィックス
 				
 			$replaceNew = true;
 		}
@@ -303,6 +311,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 				$start_time = $this->convertToDispTime($row['pd_active_start_dt'], 1/*時分*/);	// 公開期間開始時間
 				$end_date = $this->convertToDispDate($row['pd_active_end_dt']);	// 公開期間終了日
 				$end_time = $this->convertToDispTime($row['pd_active_end_dt'], 1/*時分*/);	// 公開期間終了時間
+				$cssClassSuffix = $row['pd_suffix'];			// 追加CSSクラスサフィックス
 				
 				//例外ページ
 				$this->exceptPageArray = array();
@@ -351,6 +360,10 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$this->tmpl->addVar("_widget", "end_date", $end_date);	// 公開期間終了日
 		$this->tmpl->addVar("_widget", "end_time", $end_time);	// 公開期間終了時間
 		
+		$widgetOuterClass = self::WIDGET_CSS_CLASS_HEAD . str_replace('/', '_', $widgetId);
+		$this->tmpl->addVar("_widget", "css_class", $this->convertToDispString($widgetOuterClass));	// ウィジェットCSSクラス
+		$this->tmpl->addVar("_widget", "css_class_suffix", $this->convertToDispString($cssClassSuffix));			// 追加CSSクラスサフィックス
+		
 		// パス等を設定
 		$this->tmpl->addVar('_widget', 'calendar_img', $this->getUrl($this->gEnv->getRootUrl() . self::CALENDAR_ICON_FILE));	// カレンダーアイコン
 		
@@ -481,6 +494,7 @@ class admin_mainAdjustwidgetWidgetContainer extends admin_mainBaseWidgetContaine
 		$localeText['label_always'] = $this->_('Always');		// 常時表示
 		$localeText['label_login'] = $this->_('When user in login');		// ログイン時のみ表示
 		$localeText['label_no_login'] = $this->_('When user not in login');		// 非ログイン時のみ表示
+		$localeText['label_css_class'] = $this->_('Additional CSS Class');		// 追加CSSクラス
 		$localeText['label_update'] = $this->_('Update');// 更新
 		$this->setLocaleText($localeText);
 	}
