@@ -8,9 +8,9 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2012 Magic3 Project.
+ * @copyright  Copyright 2006-2013 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: admin_ec_dispWidgetContainer.php 5353 2012-10-31 02:50:19Z fishbone $
+ * @version    SVN: $Id: admin_ec_dispWidgetContainer.php 5559 2013-01-16 13:09:11Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getContainerPath() . '/baseAdminWidgetContainer.php');
@@ -20,6 +20,8 @@ class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 	const DEFAULT_PRODUCT_COUNT = 10;				// デファオルとの表示項目数
 	const DEFAULT_TARGET_WIDGET = 'ec_main';		// 呼び出しウィジェットID
 	const DEFAULT_STOCK_VIEW_FORMAT = '0:なし;3:残り僅か($1);:あり($1)';
+	const DEFAULT_CATEGORY_LIST_TITLE = '「$1」の商品一覧';		// カテゴリー表示時タイトル
+	const DEFAULT_CATEGORY_TITLE_SEPARATOR = '-';		// デフォルトのカテゴリータイトル作成用セパレータ
 	
 	/**
 	 * コンストラクタ
@@ -56,6 +58,8 @@ class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 	{
 		$act = $request->trimValueOf('act');
 		
+		$categoryListTitle	= $request->trimValueOf('item_category_list_title');	// カテゴリー表示時タイトル
+		$categoryTitleSeparator	= $request->trimValueOf('item_category_title_separator');		// カテゴリータイトル作成用セパレータ
 		$productCount	= $request->trimValueOf('item_product_list_count');	// 商品表示数
 		$targetWidget	= $request->trimValueOf('item_cart_widget');			// カート表示ウィジェット
 		$showStock		= ($request->trimValueOf('item_show_stock') == 'on') ? 1 : 0;		// 在庫表示するかどうか
@@ -68,9 +72,13 @@ class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 			$this->checkSingleByte($targetWidget, 'カート表示ウィジェット');
 			
 			if ($this->getMsgCount() == 0){			// エラーのないとき
+				if (empty($categoryListTitle)) $categoryListTitle = self::DEFAULT_CATEGORY_LIST_TITLE;	// カテゴリー表示時タイトル
+				if (empty($categoryTitleSeparator)) $categoryTitleSeparator = self::DEFAULT_CATEGORY_TITLE_SEPARATOR;// カテゴリータイトル作成用セパレータ
 				if (empty($stockViewFormat)) $stockViewFormat	= self::DEFAULT_STOCK_VIEW_FORMAT;			// 在庫表示フォーマット
 				
 				$paramObj = new stdClass;
+				$paramObj->categoryListTitle = $categoryListTitle;	// カテゴリー表示時タイトル
+				$paramObj->categoryTitleSeparator = $categoryTitleSeparator;	// カテゴリータイトル作成用セパレータ
 				$paramObj->productCount	= $productCount;		// 商品表示数
 				$paramObj->targetWidget = $targetWidget;		// カート表示ウィジェット
 				$paramObj->showStock	= $showStock;				// 在庫表示するかどうか
@@ -86,6 +94,8 @@ class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 			}
 		} else {		// 初期表示の場合
 			// デフォルト値設定
+			$categoryListTitle = self::DEFAULT_CATEGORY_LIST_TITLE;	// カテゴリー表示時タイトル
+			$categoryTitleSeparator = self::DEFAULT_CATEGORY_TITLE_SEPARATOR;	// カテゴリータイトル作成用セパレータ
 			$productCount = self::DEFAULT_PRODUCT_COUNT;						// 商品表示数
 			$targetWidget = self::DEFAULT_TARGET_WIDGET;		// カート表示ウィジェット
 			$showStock		= 0;		// 在庫表示するかどうか
@@ -95,6 +105,8 @@ class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 			// 保存値取得
 			$paramObj = $this->getWidgetParamObj();
 			if (!empty($paramObj)){
+				$categoryListTitle = $paramObj->categoryListTitle;	// カテゴリー表示時タイトル
+				$categoryTitleSeparator = $paramObj->categoryTitleSeparator;	// カテゴリータイトル作成用セパレータ
 				$productCount = $paramObj->productCount;		// 商品表示数
 				$targetWidget = $paramObj->targetWidget;		// カート表示ウィジェット
 				$showStock		= $paramObj->showStock;				// 在庫表示するかどうか
@@ -103,8 +115,10 @@ class admin_ec_dispWidgetContainer extends baseAdminWidgetContainer
 			}
 		}
 		// 画面に書き戻す
-		$this->tmpl->addVar("_widget", "product_list_count", $productCount);		// 商品表示数
-		$this->tmpl->addVar("_widget", "cart_widget", $targetWidget);		// カート表示ウィジェット
+		$this->tmpl->addVar("_widget", "category_list_title", $this->convertToDispString($categoryListTitle));		// カテゴリー表示時タイトル
+		$this->tmpl->addVar("_widget", "category_title_separator", $this->convertToDispString($categoryTitleSeparator));	// カテゴリータイトル作成用セパレータ
+		$this->tmpl->addVar("_widget", "product_list_count", $this->convertToDispString($productCount));		// 商品表示数
+		$this->tmpl->addVar("_widget", "cart_widget", $this->convertToDispString($targetWidget));		// カート表示ウィジェット
 		$this->tmpl->addVar("_widget", "stock_view_format", $stockViewFormat);		// 在庫表示フォーマット
 		$this->tmpl->addVar("_widget", "content_no_stock", $contentNoStock);		// 在庫なし時コンテンツ
 		$checkedStr = '';
